pub enum RegisterWorkspaceDirectoryError {
AccessDenied(String),
InvalidParameterValues(String),
InvalidResourceState(String),
OperationNotSupported(String),
ResourceLimitExceeded(String),
ResourceNotFound(String),
UnsupportedNetworkConfiguration(String),
WorkspacesDefaultRoleNotFound(String),
}Expand description
Errors returned by RegisterWorkspaceDirectory
Variants
AccessDenied(String)
The user is not authorized to access a resource.
InvalidParameterValues(String)
One or more parameter values are not valid.
InvalidResourceState(String)
The state of the resource is not valid for this operation.
OperationNotSupported(String)
This operation is not supported.
ResourceLimitExceeded(String)
Your resource limits have been exceeded.
ResourceNotFound(String)
The resource could not be found.
UnsupportedNetworkConfiguration(String)
The configuration of this network is not supported for this operation, or your network configuration conflicts with the Amazon WorkSpaces management network IP range. For more information, see Configure a VPC for Amazon WorkSpaces.
WorkspacesDefaultRoleNotFound(String)
The workspaces_DefaultRole role could not be found. If this is the first time you are registering a directory, you will need to create the workspaces_DefaultRole role before you can register a directory. For more information, see Creating the workspaces_DefaultRole Role.
Implementations