RegisterWorkspaceDirectoryRequest

Struct RegisterWorkspaceDirectoryRequest 

pub struct RegisterWorkspaceDirectoryRequest {
    pub directory_id: String,
    pub enable_self_service: Option<bool>,
    pub enable_work_docs: bool,
    pub subnet_ids: Option<Vec<String>>,
    pub tags: Option<Vec<Tag>>,
    pub tenancy: Option<String>,
}

Fields

directory_id: String

The identifier of the directory. You cannot register a directory if it does not have a status of Active. If the directory does not have a status of Active, you will receive an InvalidResourceStateException error. If you have already registered the maximum number of directories that you can register with Amazon WorkSpaces, you will receive a ResourceLimitExceededException error. Deregister directories that you are not using for WorkSpaces, and try again.

enable_self_service: Option<bool>

Indicates whether self-service capabilities are enabled or disabled.

enable_work_docs: bool

Indicates whether Amazon WorkDocs is enabled or disabled. If you have enabled this parameter and WorkDocs is not available in the Region, you will receive an OperationNotSupportedException error. Set EnableWorkDocs to disabled, and try again.

subnet_ids: Option<Vec<String>>

The identifiers of the subnets for your virtual private cloud (VPC). Make sure that the subnets are in supported Availability Zones. The subnets must also be in separate Availability Zones. If these conditions are not met, you will receive an OperationNotSupportedException error.

tags: Option<Vec<Tag>>

The tags associated with the directory.

tenancy: Option<String>

Indicates whether your WorkSpace directory is dedicated or shared. To use Bring Your Own License (BYOL) images, this value must be set to DEDICATED and your AWS account must be enabled for BYOL. If your account has not been enabled for BYOL, you will receive an InvalidParameterValuesException error. For more information about BYOL images, see Bring Your Own Windows Desktop Images.